/*
 * Copyright (C) 2022 Associated Universities, Inc. Washington DC, USA.
 *
 * This file is part of NRAO Workspaces.
 *
 * Workspaces is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Workspaces is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
 */

package main

import (
	"flag"
	"ssa/iiwf_trigger/pkg/ingest"
)

func main() {
	var img_set_path string
	var capo_profile string

	flag.StringVar(&img_set_path, "path", "", "Path to a cached VLASS image set")
	flag.StringVar(&capo_profile, "prop", "/home/casa/capo/${CAPO_PROFILE}.properties", "Path to the CAPO properties file with the calibration lookup URL")
	flag.Parse()

	// Make sure a path was provided
	if len(img_set_path) == 0 {
		flag.Usage()
		return
	}

	locator := ingest.GetCalibrationLocator(img_set_path, capo_profile)
	ingest.CallIngestionEndpoint(img_set_path, locator, capo_profile)
}
