#
# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.

# pylint: disable=C0114, C0103, E0401, E0402

import pyat
from pyat.schema import ExecutionBlock, Filegroup, Project, RealfastExecutionBlock


def test_realfast_execblock_persistence():
    """
    Test for persistents of realfast execution blocks.

    :return:
    """
    p = Project()
    p.project_code = "foo"
    fg = Filegroup()
    eb = RealfastExecutionBlock(filegroup=fg, calibration_level=1, telescope="VLA", project_code="foo")

    session = pyat.schema.create_session("SDM", profile="local")
    try:
        session.add(p)
        session.add(eb)
        session.commit()
        eb2 = session.query(RealfastExecutionBlock).all()[-1]
        assert eb2 == eb
        eb3 = session.query(ExecutionBlock).get(eb2.execution_block_id)
        assert eb3 == eb
    finally:
        session.delete(eb)
        session.delete(fg)
        session.delete(p)
        session.commit()
