#!/bin/bash
#
# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
#

# Set failfast
set -e
set -o pipefail

BUILD_DIR=/lustre/aoc/cluster/pipeline/docker/workspaces/sbin
[[ -d $BUILD_DIR ]] ||  mkdir -p $BUILD_DIR

cd  apps/cli/executables/pexable/
for pexable in "$@"
do
  # Uncomment lines below to skip ingest pex build
  # if [ $pexable == "ingest" ]; then
  #   echo "Skipping $pexable"
  #   continue
  # fi
  cd  "$pexable"
  if [ -e setup.py ]; then
    pex_build_cmd="python3 setup.py bdist_pex --bdist-all --bdist-dir=\"$BUILD_DIR\" --pex-args=\"--python-shebang /home/ssa/bin/python3.8\""
    build_attempts=0
    until eval "$pex_build_cmd" || [ $build_attempts -gt 3 ] ; do
      ((build_attempts++))
      echo "PEX build failed. Attempt: $build_attempts. Retrying."; sleep 2;
    done
  else
    echo "PEX build impossible in $PWD because there is no setup.py file"
  fi
  cd ..
done
