#
# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
from enum import Enum


class LocalWorkflows(Enum):
    """
    Enum that specifies which workflows can ONLY run locally - i.e. *require* lustre access
    """

    INGEST_IMAGE = "ingest_image"
    INGEST_CAL = "ingest_cal"
    CARTA = "carta"
    DOWNLOAD = "test_download"

    @classmethod
    def values(cls):
        return cls._value2member_map_

    @classmethod
    def is_local(cls, wf_name: str):
        return wf_name in cls.values()


class RemoteWorkflows(Enum):
    """
    Enum that specifies which workflows can run remotely
    """

    SECI = "vlass_seci"
    CUBE = "vlass_coarse"
    DOWNLOAD = "test_download"  # listed as remote due to ALMA downloads running in CV, but still requires lustre access
    CARTA = "carta"
    STD_CALIBRATION = "std_calibration"
    STD_IMAGING = "std_cms_imaging"
    RESTORE = "restore_cms"
    RESTORE_IMAGING = "std_restore_imaging"

    @classmethod
    def values(cls):
        return cls._value2member_map_

    @classmethod
    def is_remote(cls, wf_name: str):
        return wf_name in cls.values()


class RemoteProcessingSites(Enum):
    """
    Enum specifying which remote sites are available
    """

    NAASC = "remote-cv"
    NMT = "remote"

    @classmethod
    def values(cls):
        return cls._value2member_map_
